const Chart = require('chart.js')
window.$ = window.jQuery = require('jquery')
const io = require('socket.io-client')

var socket = io(window.websocketServer, {
  query: {
    quizId: window.quizId,
    admin: true,
  },
})

var voteCount = window.defaultCount
var acceptAnswers = true

$(function() {
  var ctx = $('#myChart')
  window.myChart = new Chart(ctx, window.defaultConfig)

  $(window).on('keypress', function(event) {
    // If f is pressed
    if (event.which === 102) {
      showFakeResults()
    }

    // If s is pressed
    if (event.which === 115) {
      acceptAnswers = false
    }
  })
})

socket.on('connect', function(data) {
  socket.on('HYDRATE', function(data) {
    for (let index = 0; index < data.answers.length; index++) {
      for (
        let innerIndex = 0;
        innerIndex < data.answers[index].length;
        innerIndex++
      ) {
        if (data.answers[index][innerIndex] === null) {
          continue
        }

        var answerIndex = window.actualLabels.indexOf(
          data.answers[index][innerIndex][parseInt(window.questionId)],
        )
        if (answerIndex !== '-1') {
          voteCount[answerIndex]++
        }
      }
    }

    calculatePercentages()
    window.myChart.update()
  })

  socket.on('SEND_ANSWER', function(data) {
    updateVoteCount(data)
    calculatePercentages()
    if (acceptAnswers) {
      window.myChart.update()
    }
  })
})

function updateVoteCount(label) {
  var answerIndex = window.actualLabels.indexOf(label)
  voteCount[answerIndex]++
}

function calculatePercentages() {
  var totalVotes = arrSum(voteCount)

  window.myChart.data.datasets.forEach(dataset => {
    dataset.data.forEach((item, index) => {
      var votes = voteCount[index]
      dataset.data[index] = (votes / totalVotes) * 100
    })
  })
}

function showFakeResults() {
  acceptAnswers = false

  window.myChart.data.datasets.forEach(dataset => {
    dataset.data = window.defaultPercentages
  })

  window.myChart.update()
}

const arrSum = arr => arr.reduce((a, b) => a + b, 0)
