import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import TextInput from '@/Shared/TextInput'
import UserList from './UserList'

const GroupsCreateForm = data => {
  const { users, errors } = usePage()

  const [values, setValues] = useState({
    name: '',
    selectedUsers: [],
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.post(route('eventpal.groups.store'), values)
  }

  return (
    <div className='tw-w-full tw-max-w-full md:tw-max-w-3xl'>
      <form onSubmit={handleSubmit}>
        <div className='panel'>
          <div>
            <TextInput
              label='Group name'
              name='name'
              errors={errors.name}
              value={values.name}
              onChange={handleChange}
            />
          </div>
        </div>

        <UserList
          users={users}
          selectedUsers={values.selectedUsers}
          onChange={handleChange}
        />

        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light'
            href={route('eventpal.groups.index')}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to groups list
            </span>
          </InertiaLink>
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
GroupsCreateForm.layout = page => (
  <Layout area='Groups' title='Create a Group'>
    {page}
  </Layout>
)

export default GroupsCreateForm
