import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const Groups = data => {
  const groups = data.groups

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.groups.create')}
        >
          <i className='fas fa-plus' />
          Create user group
        </InertiaLink>
      </div>

      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>#</th>
              <th>Group name</th>
              <th>Number of users</th>
              <th>Date created</th>
              <th>Date updated</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {groups.map(group => (
              <tr key={group.id}>
                <td>{group.id}</td>
                <td>{group.name}</td>
                <td>{group.userCount}</td>
                <td>
                  <div className='badge badge-success'>Correct</div>
                </td>
                <td>{group.updatedDate}</td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.groups.edit', group.id)}
                    title='Edit group'
                  >
                    <span>
                      <i className='fas fa-pencil-alt fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button danger'
                    href={`/eventpal/groups/${group.id}`} // TODO: Update to form / add in modal
                    title='Delete group'
                    method='delete'
                  >
                    <span>
                      <i className='fas fa-trash-alt fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {groups.length === 0 && (
              <tr>
                <td className='no-results' colSpan='9'>
                  No groups found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
Groups.layout = page => <Layout title='Groups'>{page}</Layout>

export default Groups
