import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const QuizQuestions = data => {
  const questions = data.questions
  const quiz = data.quiz

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-light'
          href={route('eventpal.quiz.index')}
        >
          <span>
            <i className='fas fa-chevron-left' />
            Back to Quizzes
          </span>
        </InertiaLink>

        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.quiz.questions.create', quiz)}
        >
          <span>
            <i className='fas fa-plus' />
            Create Question
          </span>
        </InertiaLink>
      </div>

      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>Re-order</th>
              <th>#</th>
              <th>Question title</th>
              <th>Responses</th>
              <th>Status</th>
              <th>Question controls</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {questions.map(question => (
              <tr key={question.id}>
                <td>
                  <a
                    className='action-button'
                    href='#'
                    title='TBC | Drag me to re-order'
                  >
                    <i className='fas fa-bars fa-lg' />
                  </a>
                </td>
                <td>{question.id}</td>
                <td>{question.title}</td>
                <td>{question.responses}</td>
                <td>
                  {question.active > 0 ? (
                    <span className='badge badge-success'>Active</span>
                  ) : (
                    <span className='badge badge-danger'>Inactive</span>
                  )}
                </td>
                <td>
                  {question.active ? (
                    <InertiaLink
                      className='action-button'
                      href={route(
                        'eventpal.quiz.question.activity.de-activate',
                        [quiz, question],
                      )}
                      title='End'
                    >
                      <span>
                        <i className='fas fa-times-circle fa-lg' />
                      </span>
                    </InertiaLink>
                  ) : (
                    <InertiaLink
                      className='action-button'
                      href={route('eventpal.quiz.question.activity.activate', [
                        quiz,
                        question,
                      ])}
                      title='Start'
                    >
                      <span>
                        <i className='fas fa-play-circle fa-lg' />
                      </span>
                    </InertiaLink>
                  )}
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.question.reveal-answer', [
                      quiz,
                      question,
                    ])}
                    title='Reveal answer'
                  >
                    <span>
                      <i className='fas fa-ban fa-lg' />
                    </span>
                  </InertiaLink>
                  <a
                    className='action-button'
                    href={route('eventpal.quiz.question.results', [
                      quiz,
                      question,
                    ])}
                    title='View results'
                    rel='noopener noreferrer'
                    target='_blank'
                  >
                    <span>
                      <i className='fas fa-chart-bar fa-lg' />
                    </span>
                  </a>
                </td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.questions.answers.index', [
                      quiz,
                      question,
                    ])}
                    title='View answers'
                  >
                    <span>
                      <i className='fas fa-bars fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button'
                    href='#'
                    title='View responses'
                  >
                    <span>
                      <i className='far fa-comments fa-lg' />
                    </span>
                  </InertiaLink>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.quiz.questions.edit', [
                      quiz,
                      question,
                    ])}
                    title='Edit'
                  >
                    <span>
                      <i className='far fa-edit fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {questions.length === 0 && (
              <tr>
                <td className='no-results' colSpan='6'>
                  No questions found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
QuizQuestions.layout = page => (
  <Layout area='Quizzes' title='Question list'>
    {page}
  </Layout>
)

export default QuizQuestions
