import React, { useState } from 'react'
import PropTypes from 'prop-types'

export default function Checkbox({
  label,
  name,
  className,
  value = 0,
  onChange,
  errors = [],
  disabled,
  ...props
}) {
  const [selected, setSelected] = useState(value)

  function handleChange() {
    const value = selected === 1 ? 0 : 1

    setSelected(value)
    onChange({
      target: {
        name: name,
        value: value,
      },
    })
  }

  return (
    <div className={`tw-mb-8 ${className}`}>
      <input
        type='checkbox'
        id={name}
        name={name}
        {...props}
        className={`tw-mr-2 ${errors.length ? 'error' : ''}`}
        disabled={disabled}
        onChange={handleChange}
      />
      {label && (
        <span className='tw-text-brand-gray-dark tw-font-semibold tw-inline-block tw-text-sm'>
          {label}
        </span>
      )}
      {errors && <div className='form-error'>{errors}</div>}
    </div>
  )
}

Checkbox.propTypes = {
  className: PropTypes.string,
  disabled: PropTypes.bool,
  errors: PropTypes.array,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  value: PropTypes.number,
}
