import React from 'react'
import PropTypes from 'prop-types'

export default function SelectInput({
  label,
  name,
  className,
  children,
  errors = [],
  value = '',
  ...props
}) {
  return (
    <div className={`tw-mb-8 ${className}`}>
      {label && <label htmlFor={name}>{label}</label>}
      <select
        id={name}
        name={name}
        value={value}
        {...props}
        className={`focus:outline-none focus:shadow-outline ${
          errors.length ? 'error' : ''
        }`}
      >
        {children}
      </select>
      {errors && <div className='form-error'>{errors[0]}</div>}
    </div>
  )
}

SelectInput.propTypes = {
  children: PropTypes.array.isRequired,
  className: PropTypes.string,
  errors: PropTypes.array,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
}
