import React from 'react'
import PropTypes from 'prop-types'

export default function TextInput({
  label,
  name,
  className,
  errors = [],
  value,
  readOnly,
  ...props
}) {
  return (
    <div className={`tw-mb-8 ${className}`}>
      {label && <label htmlFor={name}>{label}</label>}
      <input
        id={name}
        name={name}
        value={value}
        {...props}
        className={`tw-border-2 tw-border-brand-border tw-appearance-none tw-w-full tw-p-3 tw-leading-tight focus:outline-none focus:shadow-outline ${
          errors.length ? 'error' : ''
        }`}
        readOnly={readOnly}
      />
      {errors && <div className='form-error'>{errors}</div>}
    </div>
  )
}

TextInput.propTypes = {
  className: PropTypes.string,
  errors: PropTypes.array,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
  readOnly: PropTypes.bool,
  value: PropTypes.string,
}
