@extends('eventpal-admin::plain')

@section('body')
    <h1 class="chart-question text-center">{{ $question->title }}</h1>
    <div class="chart-wrap">
        <canvas id="myChart" width="1680" height="740"></canvas>
    </div>
@endsection

@push('js')
    <script>
        window.websocketServer = "{!! config('eventpal-admin.socket_server.host') !!}"
        window.quizId = "{{ $quiz->id }}"
        window.questionId = "{{ $question->id }}"
        window.defaultPercentages = {!! json_encode($question->answers->pluck('default_percentage')) !!}
        window.defaultCount = {!! json_encode(array_fill(0, $question->answers->count(), 0)) !!},

        window.actualLabels = {!! $question->answers->pluck('title')->toJson() !!}

        window.labels = {!! $question->answers->pluck('title')->map(function ($title) {
                    return \Illuminate\Support\Str::limit($title, 20);
                })->toJson() !!}

        var labelFormatted = new Array();
        for(var i = 0; i < window.labels.length; i++) {
            // Add additional code here, such as:
            var formatted = formatLabel(window.labels[i], 20);
            labelFormatted.push(formatted);
        }

        window.defaultConfig = {
            type: 'bar',
            data: {
                labels: labelFormatted,
                datasets: [{
                    label: '# of Votes',
                    data: {!! json_encode(array_fill(0, $question->answers->count(), 0)) !!},
                    backgroundColor: [
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)'
                    ],
                    borderColor: [
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)',
                        'rgba(244,146,1,1)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: true,
                scales: {
                    defaultFontColor: "#fff",
                    yAxes: [{
                        scaleLabel: {
                            display: false,
                            labelString: 'Percentage',
                            fontSize: 32,
                            fontColor: "#000",
                        },
                        ticks: {
                            beginAtZero:true,
                            max:100,
                            stepSize: 25,
                            fontSize: 42,
                            fontColor: "#000",
                            fontFamily: "Arial",
                            padding: 25,
                        },
                        gridLines : {
                            color: "#000",
                            zeroLineColor: "#000",
                            display: true,
                            lineWidth: 3,
                            zeroLineWidth: 3,
                            drawBorder: false,
                            drawTicks: false
                        }
                    }],
                    xAxes: [{
                        gridLines : {
                            display: false,
                            color: "#000"
                        },
                        ticks: {
                            fontSize: 42,
                            fontColor: "#000",
                            fontFamily: "Arial",
                            autoSkip: false
                        }
                    }]
                },
                legend: {
                    display: false
                },
                tooltips: {
                    enabled: false,
                    callbacks: {
                        label: function(tooltipItem) {
                            return tooltipItem.yLabel;
                        }
                    }
                },
                hover: {
                    enabled: false,
                    animationDuration: 0
                },
            }
        }

        function formatLabel(str, maxwidth){
            var sections = [];
            var htmlStr = decodeHtml(str);
            var words = htmlStr.split(" ");
            var temp = "";

            words.forEach(function(item, index){
                if(temp.length > 0)
                {
                    var concat = temp + ' ' + item;

                    if(concat.length > maxwidth){
                        sections.push(temp);
                        temp = "";
                    }
                    else{
                        if(index == (words.length-1))
                        {
                            sections.push(concat);
                            return;
                        }
                        else{
                            temp = concat;
                            return;
                        }
                    }
                }

                if(index == (words.length-1))
                {
                    sections.push(item);
                    return;
                }

                if(item.length < maxwidth) {
                    temp = item;
                }
                else {
                    sections.push(item);
                }

            });

            return sections.join('');
        }

        function decodeHtml(html) {
            var txt = document.createElement("textarea");
            txt.innerHTML = html;
            return txt.value;
        }
    </script>
@endpush
