<?php

namespace Drp\EventPalAdmin\Http\Controllers\Quiz;

use Drp\EventPalAdmin\Http\Controllers\Controller;
use Drp\NativeEventApp\Models\Quiz;
use Drp\NativeEventApp\Models\QuizQuestion;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;

class ActivityController extends Controller
{
    public function activateQuiz(Quiz $quiz): RedirectResponse
    {
        Quiz::where('active', 1)->get()->each->update([
            'active' => 0,
        ]);

        $quiz->update([
            'active' => 1,
        ]);
        $this->moveQuizState($quiz, 'activate');

        Session::flash('success', 'Quiz Activity Updated');

        return Redirect::route('eventpal.quiz.index');
    }

    public function deactivateQuiz(Quiz $quiz): RedirectResponse
    {
        $quiz->update([
            'active' => 0,
        ]);
        $this->moveQuizState($quiz, 'deactivate');

        Session::flash('success', 'Quiz Activity Updated');

        return Redirect::route('eventpal.quiz.index');
    }

    public function activateQuestion(Quiz $quiz, QuizQuestion $question): RedirectResponse
    {
        QuizQuestion::where('active', 1)->get()->each->update([
            'active' => 0,
        ]);

        $question->update([
            'active' => 1,
        ]);

        $this->moveQuestionState($question, 'activate');

        Session::flash('success', 'Question Activity Updated');

        return Redirect::route('eventpal.quiz.questions.index', [$quiz]);
    }

    public function deactivateQuestion(Quiz $quiz, QuizQuestion $question): RedirectResponse
    {
        $question->update([
            'active' => 0,
        ]);

        $this->moveQuestionState($question, 'deactivate');

        Session::flash('success', 'Question Activity Updated');

        return Redirect::route('eventpal.quiz.questions.index', [$quiz]);
    }

    public function revealAnswer(Quiz $quiz, QuizQuestion $question): RedirectResponse
    {
        $question->operator->revealAnswer();

        Session::flash('success', 'Correct Answer Revealed');

        return Redirect::route('eventpal.quiz.questions.index', [$quiz]);
    }

    private function moveQuizState(Quiz $quiz, string $status): void
    {
        if ($status === 'activate') {
            $quiz->operator->create();
            $quiz->operator->start();

            return;
        }

        $quiz->operator->end();
    }

    private function moveQuestionState(QuizQuestion $question, string $status): void
    {
        if ($status === 'activate') {
            $question->operator->start();

            return;
        }

        $question->operator->end();
    }
}
