<?php

namespace Drp\EventPalAdmin\Http\Controllers;

use Drp\EventPalAdmin\Http\Requests\CreateSpeaker;
use Drp\NativeEventApp\Models\Speaker;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Inertia\Inertia;
use Inertia\Response;

class SpeakersController extends Controller
{
    public function index(): Response
    {
        return Inertia::render('Speakers/Index', [
            'speakers' => Speaker::orderBy('id', 'asc')->get()
                ->transform(function ($speaker) {
                    return [
                        'id' => $speaker->id,
                        'name' => $speaker->name,
                        'jobTitle' => $speaker->jobTitle,
                        'company' => $speaker->company,
                        'bio' => $speaker->bio,
                    ];
                }),
        ]);
    }

    public function create(): Response
    {
        return Inertia::render('Speakers/Create');
    }

    public function store(CreateSpeaker $request): RedirectResponse
    {
        Speaker::create($request->all());

        return Redirect::route('speakers')->with('success', 'Speaker created.');
    }

    public function edit(Speaker $speaker): Response
    {
        return Inertia::render('Speakers/Edit', [
            'speaker' => [
                'id' => $speaker->id,
                'name' => $speaker->name,
                'jobTitle' => $speaker->jobTitle,
                'company' => $speaker->company,
                'bio' => $speaker->bio,
            ],
        ]);
    }

    public function update(CreateSpeaker $request, Speaker $speaker): RedirectResponse
    {
        $speaker->update($request->all());

        return Redirect::back()->with('success', 'Speaker updated.');
    }

    public function destroy(Speaker $speaker): RedirectResponse
    {
        $speaker->delete();

        return Redirect::back()->with('success', 'Speaker deleted.');
    }
}
