<?php
Route::prefix('eventpal')
    ->name('eventpal.')
    ->middleware([
        'web',
        'admin',
    ])
    ->namespace('\Drp\EventPalAdmin\Http\Controllers')
    ->group(function (): void {
        Route::get(
            '/home',
            [
                'as' => 'dashboard',
                'uses' => 'DashboardController',
            ]
        );

        Route::get(
            '/dashboard',
            [
                'uses' => 'DashboardController',
            ]
        );

        /**
         * Quizzes
         */
        Route::namespace('Quiz')->group(function (): void {
            Route::get('quiz/activity/{quiz}/activate')
                ->name('quiz.activity.activate')
                ->uses('ActivityController@activateQuiz');

            Route::get('quiz/activity/{quiz}/de-activate')
                ->name('quiz.activity.de-activate')
                ->uses('ActivityController@deactivateQuiz');

            Route::resource('quiz', 'QuizController')
                ->names([
                    'index' => 'quiz.index',
                    'create' => 'quiz.create',
                    'store' => 'quiz.store',
                    'edit' => 'quiz.edit',
                    'update' => 'quiz.update',
                    'destroy' => 'quiz.destroy',
                ]);

            Route::get('quiz/{quiz}/sync')
                ->name('quiz.sync')
                ->uses('SyncController');

            Route::get('quiz/{quiz}/questions/{question}/results')
                ->name('quiz.question.results')
                ->uses('ResultsController');

            Route::get('quiz/{quiz}/questions/{question}/reveal-answer')
                ->name('quiz.question.reveal-answer')
                ->uses('ActivityController@revealAnswer');

            Route::get('quiz/{quiz}/questions/{question}/activity/activate')
                ->name('quiz.question.activity.activate')
                ->uses('ActivityController@activateQuestion');

            Route::get('quiz/{quiz}/questions/{question}/activity/de-activate')
                ->name('quiz.question.activity.de-activate')
                ->uses('ActivityController@deactivateQuestion');

            Route::resource('quiz.questions', 'QuizQuestionController')
                ->names([
                    'index' => 'quiz.questions.index',
                    'create' => 'quiz.questions.create',
                    'store' => 'quiz.questions.store',
                    'edit' => 'quiz.questions.edit',
                    'update' => 'quiz.questions.update',
                    'destroy' => 'quiz.questions.destroy',
                ]);

            Route::resource('quiz.questions.answers', 'AnswerController')
                ->names([
                    'index' => 'quiz.questions.answers.index',
                    'create' => 'quiz.questions.answers.create',
                    'store' => 'quiz.questions.answers.store',
                    'edit' => 'quiz.questions.answers.edit',
                    'update' => 'quiz.questions.answers.update',
                    'destroy' => 'quiz.questions.answers.destroy',
                ]);
        });

        /**
         * Feedback
         */
        Route::get('feedback')->name('feedback')->uses('FeedbackController');

        /**
         * Agenda
         */
        Route::get('agenda')
            ->name('agenda')
            ->uses('AgendaController@index');

        /**
         * Speakers
         */
        Route::resource('speakers', 'SpeakersController')
            ->names([
                'index' => 'speakers.index',
                'create' => 'speakers.create',
                'store' => 'speakers.store',
                'edit' => 'speakers.edit',
                'update' => 'speakers.update',
                'delete' => 'speakers.delete',
            ]);

        /**
         * Notifications
         */
        Route::resource('notifications', 'NotificationsController')
            ->names([
                'index' => 'notifications.index',
                'create' => 'notifications.create',
                'store' => 'notifications.store',
                'edit' => 'notifications.edit',
                'update' => 'notifications.update',
                'delete' => 'notifications.destroy',
            ]);

        /**
         * User Groups
         */
        Route::resource('groups', 'GroupsController')
            ->names([
                'index' => 'groups.index',
                'create' => 'groups.create',
                'store' => 'groups.store',
                'edit' => 'groups.edit',
                'update' => 'groups.update',
                'delete' => 'groups.destroy',
            ]);

        /**
         * Forms
         */
        Route::get('forms/{form}/qna/moderate', [
            'as' => 'forms.qna.moderate',
            'uses' => 'Forms\QnA\ModerateController',
        ]);
        Route::get('forms/{form}/qna/facilitate', [
            'as' => 'forms.qna.facilitate',
            'uses' => 'Forms\QnA\FacilitateController',
        ]);

        Route::patch('forms/{form}/qna/{record}', [
            'as' => 'forms.qna.status',
            'uses' => 'Forms\QnA\StatusController',
        ]);

        Route::resource('forms', 'Forms\FormController')
            ->names([
                'index' => 'forms.index',
                'create' => 'forms.create',
                'store' => 'forms.store',
                'edit' => 'forms.edit',
                'update' => 'forms.update',
                'delete' => 'forms.update',
            ]);

        Route::resource('forms.records', 'Forms\RecordController')
            ->names([
                'index' => 'forms.records.index',
                'create' => 'forms.records.create',
                'store' => 'forms.records.store',
                'edit' => 'forms.records.edit',
                'update' => 'forms.records.update',
                'delete' => 'forms.records.update',
            ]);
    });
